export function getFileTree(path: any): Promise<FileTree>;
export function revealFolder(folderpath: any): void;
export namespace cq {
    /**
    * Evaluates Extendscript and Returns Error if thrown
    * Credit: Justin Taylor
    *
    * @param {!String} script ExtendScript Code to be executed
    * @return {!Promise(resolve)} Returns promise with funciton result or error message
    */
    function evalES(script: string): Promise<any>;
    /**
    * Registers every possible key command allowed by app
    * Credit: Justin Taylor
    *
    * @param {!String} script ExtendScript Code to be executed
    * @return {!Promise(resolve)} Returns promise with funciton result or error message
    */
    function keyRegisterOverride(): Promise<any>;
    /**
    * Prevents dragging of external URLs into the panel
    * Credit: Justin Taylor
    */
    function dropDisable(): void;
    /**
    * Map value from one range to another
    * Credit: Justin Taylor
    *
    * @param {!Number} num current value
    * @param {!Number} in_min input minimum value
    * @param {!Number} in_max input maximum value
    * @param {!Number} out_min output minimum value
    * @param {!Number} out_max output maximum value
    * @return mapped value
    */
    function rangeMap(num: number, in_min: number, in_max: number, out_min: number, out_max: number): number;
    /**
    * Parse all Command IDs for After Effects from dictionary file
    * Credit: Justin Taylor
    *
    * @return Menu ID object
    */
    function cmdIDs(): Promise<any>;
    /**
    * Get the file extension for a Media Encoder export preset file
    *
    * Note: AfterCodecs shares a FileType number for both mov and mp4,
    * so afterCodecsExtension() drills down to the extension param.
    *
    * Credit: Justin Taylor
    *
    * @param {!String} path path to EXR file
    * @return {!String} file extension
    */
    function getEprExtension(eprPath: any): string;
    function createLayerStylesFolder(): Promise<any>;
    function selectFolderDialog(message?: string): Promise<any>;
    function getFileDirectoryTree(folder: any): Promise<any>;
    function getPresets(folderpath: any): Promise<any>;
    function smallCss(): Promise<any>;
}
export class FileTree {
    constructor(path: any, creator?: typeof FileTree);
    creator: typeof FileTree;
    exists: boolean;
    path: any;
    name: any;
    children: any[];
    type: string | undefined;
    existing(): void;
    getChildren(): any[] | undefined;
}
